import { defineComponent, watch, reactive, PropType } from 'vue';
import Map from '@/components/MapView';
import { Notify, Button } from 'vant';
/** @ts-ignore */
import icon_map_location from '@/assets/icons/home/icon_map_location@2x.png';

// const solution = 16857;


export default defineComponent({
  props: {
    address: String,
    latitude: String, // 纬度
    longitude: String, // 经度
    locations: String, // 经度,纬度
    readonly: Boolean,
    onRestPositon: Function,
    onChoose: Function as PropType<(name?: string) => void>,
  },
  setup(props, ctx) {
    const state = reactive({
      map: null as any,
      _marker: null as any,
      loading: false,
      postition: {
        longitude: props.longitude,
        latitude: props.latitude,
        name: props.address,
      },
    });

    watch(
      () => props.address,
      (next, pre) => {
        if (!next) return;
        if (next === pre) return;

        if (!state.map) {
          Notify({
            type: 'danger',
            message: '地图插件初始化异常, 请刷新页面 (Ctrl + R)',
          });

          return;
        }
        state.loading = true;

        fetch(
          `https://minedata.cn/service/lbs/search/v1/keywords?keywords=${next}&city=宿迁&citylimit=true&page_idx=1&page_size=10&key=${window.key}`,
        )
          .then((res) => res.json())
          .then((data) => {
            state.loading = false;

            if (!data) {
              Notify({
                type: 'danger',
                message: '宿迁市查询不到该地址, 请核对地址',
              });
              return;
            }
            // 经纬度坐标。经度在前，纬度在后，经度和纬度用“,”分割
            const [longitude, latitude] = (
              (data?.pois?.[0]?.location as string) ?? ''
            ).split(',');

            const name = data?.pois?.[0]?.name ?? '';

            if (!longitude && !latitude) {
              Notify({
                type: 'danger',
                message: '宿迁市查询不到该地址, 请核对地址',
              });
              return;
            }

            state.postition = {
              longitude,
              latitude,
              name,
            };

            state.map.flyTo({
              center: [Number(longitude), Number(latitude)],
              zoom: 14,
              bearing: 0,
              pitch: 0,
              duration: 2000,
            });
            if (state.map && state._marker) {
              state._marker.remove();
              state._marker = null;
            }
            if (state.map) {
              var el = document.createElement('div');
              el.id = 'marker';
              el.style.backgroundImage = `url(${icon_map_location})`;
              el.style.backgroundSize = 'cover';
              el.style.width = '24px';
              el.style.height = '24px';
              el.style.borderRadius = '50%';

              const popup = new window.minemap.Popup({
                closeOnClick: false,
                closeButton: false,
                offset: [0, -15],
              }).setText(name);

              state._marker = new window.minemap.Marker(el, {
                offset: [-12, -12],
              })
                .setLngLat([Number(longitude), Number(latitude)])
                .setPopup(popup)
                .addTo(state.map);
              window._marker = state._marker;
            }
            state._marker.togglePopup();
          })
          .catch((err) => {
            console.log(err);
            Notify({
              type: 'danger',
              message: '系统异常, 请稍后重试!',
            });
          });
      },
    );

    const handleResetPosition = () => {
      state._marker?.remove();
      state._marker = null;

      props.onRestPositon && props.onRestPositon();
    };
    const handleSavePosition = () => {
      if (!state.postition.latitude || !state.postition.longitude) {
        Notify({
          type: 'danger',
          message: '请输入地址!',
        });
        return;
      }
      Notify({
        type: 'success',
        message: '选择成功!',
      });
      ctx.emit('update:latitude', state.postition.latitude);
      ctx.emit('update:longitude', state.postition.longitude);
      props.onChoose && props.onChoose(state.postition.name);
      ctx.emit(
        'update:locations',
        `${state.postition.longitude},${state.postition.latitude}`,
      );
    };

    return () => (
      <div
        // v-loading={state.loading}
        style={{
          marginTop: '10px',
          // marginRight: props.readonly ? '0' : '80px',
          backgroundColor: '#fff',
          padding: '10px 20px 10px',
          position: 'relative',
        }}>
        <Map
          v-model:map={state.map}
          style={{
            height: '240px',
            borderRadius: '2px',
            boxShadow: '0px 0px 0px 1px #d9d9d9;',
          }}
        />

        {!props.readonly && (
          <div
            style={{
              backgroundColor: '#fff',
              padding: '10px 20px 10px',
              marginLeft: '-20px',
              // position: 'absolute',
              // bottom: '0',
              // right: '-80px',
              // display: 'flex',
              // flexDirection: 'column',
            }}>
            <Button size="small" onClick={handleResetPosition}>
              重置
            </Button>
            <span style={{ padding: '8px ' }} />
            <Button type="primary" size="small" onClick={handleSavePosition}>
              确认
            </Button>
          </div>
        )}
      </div>
    );
  },
});
