import { defineComponent, ref, watch, PropType, computed } from 'vue';
import { useRoute, useRouter } from 'vue-router';
import clsx from 'clsx';
import { MENUS_DUTY, PATH_LINK_NAV_BAR_MENU } from '@/constants/constants';
import './index.scss';
import useMenus from '@/hooks/useMenus';
import { useCommonStore } from '@/store';

const MENUS_TYPE = {
  MENUS_DUTY,
};

interface MenusProps {
  type: 'MENUS_INCIDENT';
  onChange: (status: string) => void;
}

export default defineComponent({
  name: 'Menus',
  props: {
    type: {
      type: String as PropType<keyof typeof PATH_LINK_NAV_BAR_MENU>,
      required: true,
    },
    onChange: Function,
  },
  setup(props) {
    const router = useRouter();
    const route = useRoute();

    const currentPath = computed(() => route.path);

    const store = useCommonStore();

    const { MENUS_INCIDENT, MENUS_EMERGENCY_PLAN, MENUS_EMERGENCY_RESOURCES } =
      useMenus();

    const handlerEnter = (item: { name: string; path: string }) => {
      router.push(item.path);
      props.onChange && props.onChange(item);
    };

    const menu = computed<{
      title: { name: string; path?: string | null };
      items?: {
        name: string;
        path: string;
        icon?: string;
      }[];
    }>(() => {
      switch (props.type) {
        case 'duty-management':
          return MENUS_DUTY;
        default:
        case 'incident-management':
          return MENUS_INCIDENT.value;
        case 'emergency-resources':
          return MENUS_EMERGENCY_RESOURCES.value;
        case 'emergency-plan':
          return MENUS_EMERGENCY_PLAN.value;
      }
    });

    return () => (
      <div class="sider-menus-container">
        <el-skeleton
          rows={5}
          animated
          throttle={500}
          loading={store.loading}
          v-slots={{
            template: () => (
              <>
                <div style={{ padding: '20px' }}>
                  <el-skeleton-item
                    variant="text"
                    style={{
                      height: '26px',
                      width: '60%',
                    }}
                  />
                  <div
                    style={{
                      display: 'flex',
                      alignItems: 'center',
                      justifyItems: 'space-between',
                      margin: '9px 0',
                      height: '22px',
                    }}>
                    <el-skeleton-item
                      variant="text"
                      style={{ width: '16px', marginRight: '10px' }}
                    />

                    <el-skeleton-item variant="text" style={{}} />
                  </div>
                  <div
                    style={{
                      display: 'flex',
                      alignItems: 'center',
                      justifyItems: 'space-between',
                      margin: '9px 0',
                      height: '22px',
                    }}>
                    <el-skeleton-item
                      variant="text"
                      style={{ width: '16px', marginRight: '10px' }}
                    />

                    <el-skeleton-item variant="text" style={{ width: '60%' }} />
                  </div>
                  <div
                    style={{
                      display: 'flex',
                      alignItems: 'center',
                      justifyItems: 'space-between',
                      margin: '9px 0',
                      height: '22px',
                    }}>
                    <el-skeleton-item
                      variant="text"
                      style={{ width: '16px', marginRight: '10px' }}
                    />

                    <el-skeleton-item variant="text" style={{}} />
                  </div>
                </div>
              </>
            ),
          }}>
          <div
            class="sider-menu-title"
            onClick={() => {
              if (menu.value.title.path) {
                router.push(menu.value.title.path);
              }
            }}>
            {menu.value.title.name}
          </div>

          {menu.value.items?.map((item) => (
            <div
              class={clsx('sider-menu-item', {
                selected: currentPath.value.includes(item.path),
              })}
              role="menuitem"
              tabindex="0"
              onKeypress={() => handlerEnter(item)}
              onClick={() => handlerEnter(item)}>
              {item.icon ? <item.icon /> : <span>•</span>}
              {item.name}
            </div>
          ))}
        </el-skeleton>
      </div>
    );
  },
});
